interface ProjectsInCollections {
    /**
     * Collection ID.
     * @format GUID
     */
    collectionId?: string;
    /** Project object. */
    project?: Project;
    /**
     * Index that determines the placement of a project within the collection.  <br />
     *
     * Default: [Epoch](https://www.epoch101.com/) timestamp. <br />
     */
    sortOrder?: number | null;
    /**
     * Project placement ID.
     * @readonly
     * @format GUID
     */
    _id?: string | null;
}
interface Project extends ProjectCoverOneOf {
    /** Project cover image. */
    coverImage?: Image;
    /** Project cover video. */
    coverVideo?: Video;
    /**
     * Project ID.
     * @readonly
     * @format GUID
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the project is updated. To prevent conflicting changes, the existing revision must be passed when updating the project object.
     * @readonly
     */
    revision?: string | null;
    /**
     * Project title.
     * @maxLength 100
     */
    title?: string | null;
    /** Project description. */
    description?: string | null;
    /** Whether the project is hidden from the portfolio. Default: `false` */
    hidden?: boolean | null;
    /**
     * IDs of the collections that include the project.
     * @format GUID
     * @maxSize 1000
     */
    collectionIds?: string[];
    /** Project details. */
    details?: ProjectDetail[];
    /** Project slug. */
    slug?: string | null;
    /**
     * Date and time the project was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the project was updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Project page URL and relative path. Returned when `includePageUrl` is `true` in the request.
     * @readonly
     */
    url?: string;
    /** Project SEO data. */
    seoData?: SeoSchema;
}
/** @oneof */
interface ProjectCoverOneOf {
    /** Project cover image. */
    coverImage?: Image;
    /** Project cover video. */
    coverVideo?: Video;
}
interface Image {
    /** Information about the Wix Media image. */
    imageInfo?: string;
    /** Focal point of the image. */
    focalPoint?: Point;
}
declare enum ImageType {
    UNDEFINED = "UNDEFINED",
    WIX_MEDIA = "WIX_MEDIA",
    EXTERNAL = "EXTERNAL"
}
interface Point {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
}
interface UnsharpMasking {
    /**
     * Unsharp masking amount. Controls the sharpening strength. <br />
     *
     * Min: `0` <br />
     * Max: `5`
     * @max 5
     */
    amount?: number | null;
    /** Unsharp masking radius in pixels. Controls the sharpening width. */
    radius?: number | null;
    /**
     * Unsharp masking threshold. Controls how different neighboring pixels must be for shapening to apply. <br />
     *
     * Min: `0` <br />
     * Max: `1`
     * @max 1
     */
    threshold?: number | null;
}
interface Video {
    /** Information about the Wix Media video. */
    videoInfo?: string;
    /** Manually defined Video duration in milliseconds. */
    durationInMillis?: number | null;
}
interface VideoResolution {
    /** Video URL.  Required. */
    url?: string;
    /** Video height. Required. */
    height?: number;
    /** Video width.  Required. */
    width?: number;
    /** Video format for example, mp4, hls.  Required. */
    format?: string;
    /** Video quality for example 480p, 720p. */
    quality?: string | null;
    /** Video filename. */
    filename?: string | null;
}
/**
 * Project label.
 * One of:
 * + `text`
 * + `link`
 */
interface ProjectDetail extends ProjectDetailValueOneOf {
    /** Project label in plain text format. */
    text?: string;
    /** Project label in link format. */
    link?: DetailsLink;
    /** Project label. */
    label?: string;
}
/** @oneof */
interface ProjectDetailValueOneOf {
    /** Project label in plain text format. */
    text?: string;
    /** Project label in link format. */
    link?: DetailsLink;
}
interface DetailsLink {
    /** Display text of the link. */
    text?: string | null;
    /**
     * Target URL of the link.
     * @format WEB_URL
     */
    url?: string | null;
    /**
     * Whether the link opens in a new tab or window. One of:
     * * `'_blank'`: The link opens in a new tab or window.
     * * `'_self'`: The link opens in the same tab or window.
     */
    target?: string | null;
}
interface ProjectSource {
    /**
     * App definition id
     * @immutable
     */
    appDefId?: string;
    /**
     * External source id
     * @immutable
     */
    externalId?: string;
    /**
     * Source name
     * @maxLength 100
     * @immutable
     */
    sourceName?: string;
    /**
     * Source description
     * @immutable
     */
    description?: string | null;
    /**
     * link to external source
     * @format WEB_URL
     */
    link?: string | null;
    /** Sync status */
    syncStatus?: SyncStatusWithLiterals;
    /** fields that are synced from external source, should be blocked to update in UI */
    notEditableFields?: string[];
    /** last date the project was synced */
    lastSync?: Date | null;
}
declare enum SyncStatus {
    SYNCED = "SYNCED",
    SYNCING = "SYNCING",
    NOT_SYNCED = "NOT_SYNCED"
}
/** @enumType */
type SyncStatusWithLiterals = SyncStatus | 'SYNCED' | 'SYNCING' | 'NOT_SYNCED';
/**
 * The SEO schema object contains data about different types of meta tags. It makes sure that the information about your page is presented properly to search engines.
 * The search engines use this information for ranking purposes, or to display snippets in the search results.
 * This data will override other sources of tags (for example patterns) and will be included in the <head> section of the HTML document, while not being displayed on the page itself.
 */
interface SeoSchema {
    /** SEO tag information. */
    tags?: Tag[];
    /** SEO general settings. */
    settings?: Settings;
}
interface Keyword {
    /** Keyword value. */
    term?: string;
    /** Whether the keyword is the main focus keyword. */
    isMain?: boolean;
    /**
     * The source that added the keyword terms to the SEO settings.
     * @maxLength 1000
     */
    origin?: string | null;
}
interface Tag {
    /**
     * SEO tag type.
     *
     *
     * Supported values: `title`, `meta`, `script`, `link`.
     */
    type?: string;
    /**
     * A `{"key": "value"}` pair object where each SEO tag property (`"name"`, `"content"`, `"rel"`, `"href"`) contains a value.
     * For example: `{"name": "description", "content": "the description itself"}`.
     */
    props?: Record<string, any> | null;
    /** SEO tag meta data. For example, `{"height": 300, "width": 240}`. */
    meta?: Record<string, any> | null;
    /** SEO tag inner content. For example, `<title> inner content </title>`. */
    children?: string;
    /** Whether the tag is a custom tag. */
    custom?: boolean;
    /** Whether the tag is disabled. */
    disabled?: boolean;
}
interface Settings {
    /**
     * Whether the Auto Redirect feature, which creates `301 redirects` on a slug change, is enabled.
     *
     *
     * Default: `false` (Auto Redirect is enabled.)
     */
    preventAutoRedirect?: boolean;
    /**
     * User-selected keyword terms for a specific page.
     * @maxSize 5
     */
    keywords?: Keyword[];
}
interface QueryProjectInCollectionsRequest {
    /** Query options. */
    query?: QueryV2;
    /**
     * Whether to include the project's relative path and full URL in the response.
     * Default: `false`
     */
    includePageUrl?: boolean | null;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about [filtering](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#filters).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about [sorting](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#sorting).
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryProjectInCollectionsResponse {
    /** List of projects and their placement within the specified collections. */
    projectInCollections?: ProjectsInCollections[];
    /** Paging metadata. */
    metadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface UpdateProjectOrderInCollectionRequest {
    /**
     * ID of the project to update.
     * @format GUID
     */
    projectId: string;
    /**
     * Collection ID.
     * @format GUID
     */
    collectionId: string;
    /** Index that determines the placement of a project within the collection. */
    sortOrder: number | null;
}
interface UpdateProjectOrderInCollectionResponse {
    /** Updated project placement within the specified collection. */
    projectInCollection?: ProjectsInCollections;
}
interface ProjectOrderInCollectionUpdatedEvent {
    /**
     * ID of the project to update.
     * @format GUID
     */
    projectId?: string;
    /**
     * Collection ID.
     * @format GUID
     */
    collectionId?: string;
    /** Index that determines the placement of a project within the collection. */
    sortOrder?: number | null;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface ProjectInCollectionProjectOrderInCollectionUpdatedEnvelope {
    data: ProjectOrderInCollectionUpdatedEvent;
    metadata: EventMetadata;
}
interface UpdateProjectOrderInCollectionIdentifiers {
    /**
     * ID of the project to update.
     * @format GUID
     */
    projectId: string;
    /**
     * Collection ID.
     * @format GUID
     */
    collectionId: string;
}

export { type EntityDeletedEvent as A, type ActionEvent as B, type CursorPaging as C, type DetailsLink as D, type EntityCreatedEvent as E, type IdentificationData as F, type IdentificationDataIdOneOf as G, type BaseEventMetadata as H, ImageType as I, type EventMetadata as J, type Keyword as K, type MessageEnvelope as M, type ProjectInCollectionProjectOrderInCollectionUpdatedEnvelope as P, type QueryProjectInCollectionsRequest as Q, type RestoreInfo as R, SyncStatus as S, type Tag as T, type UpdateProjectOrderInCollectionIdentifiers as U, type Video as V, WebhookIdentityType as W, type UpdateProjectOrderInCollectionResponse as a, SortOrder as b, type ProjectsInCollections as c, type Project as d, type ProjectCoverOneOf as e, type Image as f, type Point as g, type UnsharpMasking as h, type VideoResolution as i, type ProjectDetail as j, type ProjectDetailValueOneOf as k, type ProjectSource as l, type SeoSchema as m, type Settings as n, type QueryV2 as o, type QueryV2PagingMethodOneOf as p, type Sorting as q, type Paging as r, type QueryProjectInCollectionsResponse as s, type PagingMetadataV2 as t, type Cursors as u, type UpdateProjectOrderInCollectionRequest as v, type ProjectOrderInCollectionUpdatedEvent as w, type DomainEvent as x, type DomainEventBodyOneOf as y, type EntityUpdatedEvent as z };
